function [ MTdata ] = read_data(cfile)
%%
%%  [ MTdata ] = read_data(cfile);
%%    MTdata: Structure that contains
%%            Zij.r:  Real part of the Z's
%%            Zij.i: Image part of the Z's
%%            %%  [ Zxx Zxy ]
%%            %%  [ Zyx Zyy ]
%%
%%            per: periods
%%
%%            Ns: number of sites
%%            Np: number of periods
%%            Nr: number of record (4 or 8)
%%                Nr=4: Zxy+Zyx
%%                Nr=8: Zxx+Zxy+Zyx+Zyy
%%
%%            Loc.east:  East position of the MT sites
%%            Loc.north: North position of the MT sites
%%
%%  READ WS3Dinv INPUT/OUTPUT DATA FILE
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% example
%% cdata  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.data';
%% cderr  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.error';
%% cresp  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d_resp.05';
%%

% init
MTdata = [];

% open file / exit if bad file
fid = fopen(cfile,'r'); if ( fid <0 ),disp([cfile ' not read!']);return;end

% start reading
dat = fscanf(fid,'%d',3); %% Dimensions
Ns = dat(1);
Np = dat(2);
Nr = dat(3);
ctmp = fgets(fid); 

ctmp = fgets(fid); %% Station_Location: N-S
dstx = fscanf(fid,'%f',Ns);
ctmp = fgets(fid); 

ctmp = fgets(fid);%% Station_Location: E-W
dsty = fscanf(fid,'%f',Ns);
ctmp = fgets(fid);

per = zeros(Np,1);
for ip = 1:Np
    ctmp = fgets(fid);%% DATA_Period:   0.1000E+00
    per( ip ) = str2double( ctmp(findstr(ctmp,':')+1:end) );
    data = fscanf(fid,'%f',[Nr Ns]);
    ctmp = fgets(fid);
    ZRes(ip,:,:) = data(:,:);
end
fclose(fid);

is = 1:Ns;
for ip = 1:Np
    if (Nr==8)
        RZxx(ip,is) = ZRes(ip,1,is);
        IZxx(ip,is) = ZRes(ip,2,is);
        RZxy(ip,is) = ZRes(ip,3,is);
        IZxy(ip,is) = ZRes(ip,4,is);
        RZyx(ip,is) = ZRes(ip,5,is);
        IZyx(ip,is) = ZRes(ip,6,is);
        RZyy(ip,is) = ZRes(ip,7,is);
        IZyy(ip,is) = ZRes(ip,8,is);
    else
        RZxx(ip,is) = 0.;
        IZxx(ip,is) = 0.;
        RZxy(ip,is) = ZRes(ip,1,is);
        IZxy(ip,is) = ZRes(ip,2,is);
        RZyx(ip,is) = ZRes(ip,3,is);
        IZyx(ip,is) = ZRes(ip,4,is);
        RZyy(ip,is) = 0.;
        IZyy(ip,is) = 0.;
    end
end

%% Output
MTdata.per   = per;
MTdata.Zxx.r = RZxx; MTdata.Zxx.i = IZxx;
MTdata.Zxy.r = RZxy; MTdata.Zxy.i = IZxy;
MTdata.Zyx.r = RZyx; MTdata.Zyx.i = IZyx;
MTdata.Zyy.r = RZyy; MTdata.Zyy.i = IZyy;

MTdata.Ns = Ns;
MTdata.Np = Np;
MTdata.Nr = Nr;

MTdata.loc.east  = dsty;
MTdata.loc.north = dstx;

MTdata.Zxx.rho  = MTdata.Zxx.r; MTdata.Zxx.phs  = MTdata.Zxx.i;
MTdata.Zxy.rho  = MTdata.Zxy.r; MTdata.Zxy.phs  = MTdata.Zxy.i;
MTdata.Zyx.rho  = MTdata.Zyx.r; MTdata.Zyx.phs  = MTdata.Zyx.i;
MTdata.Zyy.rho  = MTdata.Zyy.r; MTdata.Zyy.phs  = MTdata.Zyy.i;
for is=1:Ns
    
    [ rho , phs ] = convert( MTdata.per , MTdata.Zxx.r(:,is) , MTdata.Zxx.i(:,is) );
    MTdata.Zxx.rho(:,is) = rho; 
    MTdata.Zxx.phs(:,is) = phs;
    
    [ rho , phs ] = convert( MTdata.per , MTdata.Zxy.r(:,is) , MTdata.Zxy.i(:,is) );
    MTdata.Zxy.rho(:,is) = rho; 
    MTdata.Zxy.phs(:,is) = phs;
    
    [ rho , phs ] = convert( MTdata.per , MTdata.Zyx.r(:,is) , MTdata.Zyx.i(:,is) );
    MTdata.Zyx.rho(:,is) = rho; 
    MTdata.Zyx.phs(:,is) = phs;
    
    [ rho , phs ] = convert( MTdata.per , MTdata.Zyy.r(:,is) , MTdata.Zyy.i(:,is) );
    MTdata.Zyy.rho(:,is) = rho; 
    MTdata.Zyy.phs(:,is) = phs;
    
end



function [ rho , phs ] = convert( per , zr , zi )
%%
%% Convert for app.resistivity and phase now
%% Equatioin are : 
%%   Z = conj( complex( zr , zi ) )  %% because convention of WS
%%   rho = ( |Z|^2 )/( w mu ) with mu = 4 pi 1e-7, and w = 2 pi f = 2 pi / per
%%   phs = arg( z ) = atan( z.i / z.r )*180/pi [deg]
%%
    z = conj( complex( zr , zi ) ); 
    rho = ( abs( z ).^2 )./( ( 2 * pi ./ per ) * ( 2 * pi * 1e-7 ) );
    phs = angle( z )*180/pi;
